CONTINUE_FLAG_VALUE: float = 0.0
TERMINATE_FLAG_VALUE: float = 1.0
N_DATA_INTACT: int = 5
